<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="el">
<context>
    <name>AsciiFile</name>
    <message>
        <location filename="../asciifile/asciifile.cpp" line="35"/>
        <location filename="../asciifile/asciifile.cpp" line="41"/>
        <source>Read ascii points</source>
        <translation>Ανάγνωση σημείων ascii</translation>
    </message>
</context>
<context>
    <name>ImportShp</name>
    <message>
        <location filename="../importshp/importshp.cpp" line="40"/>
        <source>Import ESRI Shapefile</source>
        <translation>Εισαγωγή ESRI Shapefile</translation>
    </message>
</context>
<context>
    <name>LC_Align</name>
    <message>
        <location filename="../align/align.cpp" line="20"/>
        <location filename="../align/align.cpp" line="27"/>
        <source>Align</source>
        <translation>Στοίχιση</translation>
    </message>
    <message>
        <location filename="../align/align.cpp" line="40"/>
        <source>first base point:</source>
        <translation>πρώτο σημείο βάσης:</translation>
    </message>
    <message>
        <location filename="../align/align.cpp" line="42"/>
        <source>first target point:</source>
        <translation>πρώτο σημείο προορισμού:</translation>
    </message>
    <message>
        <location filename="../align/align.cpp" line="44"/>
        <source>second base point:</source>
        <translation>δεύτερο σημείο βάσης:</translation>
    </message>
    <message>
        <location filename="../align/align.cpp" line="46"/>
        <source>second target point:</source>
        <translation>δεύτερο σημείο προορισμού:</translation>
    </message>
</context>
<context>
    <name>LC_Gear</name>
    <message>
        <location filename="../gear/gear.cpp" line="33"/>
        <source>Gear creation plugin</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../gear/gear.cpp" line="40"/>
        <source>Gear plugin</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>LC_List</name>
    <message>
        <location filename="../list/list.cpp" line="23"/>
        <location filename="../list/list.cpp" line="30"/>
        <source>List entities</source>
        <translation>Απαρίθμηση οντοτήτων</translation>
    </message>
    <message>
        <location filename="../list/list.cpp" line="46"/>
        <source>n</source>
        <translation>n</translation>
    </message>
    <message>
        <location filename="../list/list.cpp" line="60"/>
        <source>Empty Entity</source>
        <translation>Κενή οντότητα</translation>
    </message>
    <message>
        <location filename="../list/list.cpp" line="67"/>
        <source>X</source>
        <translation>X</translation>
    </message>
    <message>
        <location filename="../list/list.cpp" line="67"/>
        <source>Y</source>
        <translation>Y</translation>
    </message>
    <message>
        <location filename="../list/list.cpp" line="77"/>
        <source>Layer</source>
        <translation>Στρώση</translation>
    </message>
    <message>
        <location filename="../list/list.cpp" line="79"/>
        <source>Color</source>
        <translation>Χρώμα</translation>
    </message>
    <message>
        <location filename="../list/list.cpp" line="80"/>
        <source>Line type</source>
        <translation>Τύπος γραμμής</translation>
    </message>
    <message>
        <location filename="../list/list.cpp" line="81"/>
        <source>Line thickness</source>
        <translation>Πάχος γραμμής</translation>
    </message>
    <message>
        <location filename="../list/list.cpp" line="82"/>
        <source>ID</source>
        <translatorcomment>εναλλακτικά {αναγνωριστικό, ταυτότητα}</translatorcomment>
        <translation>ID</translation>
    </message>
    <message>
        <location filename="../list/list.cpp" line="88"/>
        <source>POINT</source>
        <translation>ΣΗΜΕΙΟ</translation>
    </message>
    <message>
        <location filename="../list/list.cpp" line="89"/>
        <location filename="../list/list.cpp" line="218"/>
        <source>in point</source>
        <translation>σε σημείο</translation>
    </message>
    <message>
        <location filename="../list/list.cpp" line="94"/>
        <source>LINE</source>
        <translation>ΓΡΑΜΜΗ</translation>
    </message>
    <message>
        <location filename="../list/list.cpp" line="99"/>
        <source>from point</source>
        <translation>από σημείο</translation>
    </message>
    <message>
        <location filename="../list/list.cpp" line="102"/>
        <source>to point</source>
        <translation>προς σημείο</translation>
    </message>
    <message>
        <location filename="../list/list.cpp" line="107"/>
        <location filename="../list/list.cpp" line="131"/>
        <source>length</source>
        <translation>μήκος</translation>
    </message>
    <message>
        <location filename="../list/list.cpp" line="112"/>
        <source>Angle in XY plane</source>
        <translation>Γωνία στο επίπεδο XY</translation>
    </message>
    <message>
        <location filename="../list/list.cpp" line="113"/>
        <source>Inc.</source>
        <translatorcomment>TODO CHECKME είναι inclination το αγγλικό;</translatorcomment>
        <translation>Κλίση.</translation>
    </message>
    <message>
        <location filename="../list/list.cpp" line="118"/>
        <source>ARC</source>
        <translation>ΤΟΞΟ</translation>
    </message>
    <message>
        <location filename="../list/list.cpp" line="119"/>
        <location filename="../list/list.cpp" line="135"/>
        <location filename="../list/list.cpp" line="145"/>
        <source>center point</source>
        <translation>κέντρο</translation>
    </message>
    <message>
        <location filename="../list/list.cpp" line="125"/>
        <location filename="../list/list.cpp" line="139"/>
        <location filename="../list/list.cpp" line="222"/>
        <source>radius</source>
        <translation>ακτίνα</translation>
    </message>
    <message>
        <location filename="../list/list.cpp" line="126"/>
        <source>initial angle</source>
        <translation>αρχική γωνία</translation>
    </message>
    <message>
        <location filename="../list/list.cpp" line="127"/>
        <source>final angle</source>
        <translation>τελική γωνία</translation>
    </message>
    <message>
        <location filename="../list/list.cpp" line="134"/>
        <source>CIRCLE</source>
        <translation>ΚΥΚΛΟΣ</translation>
    </message>
    <message>
        <location filename="../list/list.cpp" line="140"/>
        <source>circumference</source>
        <translation>περιφέρεια</translation>
    </message>
    <message>
        <location filename="../list/list.cpp" line="141"/>
        <source>area</source>
        <translation>εμβαδό</translation>
    </message>
    <message>
        <location filename="../list/list.cpp" line="144"/>
        <source>ELLIPSE</source>
        <translation>ΕΛΛΕΙΨΗ</translation>
    </message>
    <message>
        <location filename="../list/list.cpp" line="148"/>
        <source>major axis</source>
        <translation>κύριος άξονας</translation>
    </message>
    <message>
        <location filename="../list/list.cpp" line="166"/>
        <source>CONSTRUCTIONLINE</source>
        <translatorcomment>CHECKME αυτοσχεδιαστική μετάφραση, καθώς και το &quot;βοηθητική&quot; έχει χρησιμοποιηθεί για το &quot;extension&quot; και ίσως είναι κάτι διαφορετικό</translatorcomment>
        <translation>ΚΑΤΑΣΚΕΥΑΣΤΙΚΗΓΡΑΜΜΗ</translation>
    </message>
    <message>
        <location filename="../list/list.cpp" line="169"/>
        <source>OVERLAYBOX</source>
        <translation>ΠΛΑΙΣΙΟΕΠΙΚΑΛΥΨΗΣ</translation>
    </message>
    <message>
        <location filename="../list/list.cpp" line="172"/>
        <source>SOLID</source>
        <translation>ΣΥΜΠΑΓΕΣ</translation>
    </message>
    <message>
        <location filename="../list/list.cpp" line="176"/>
        <source>MTEXT</source>
        <translation>ΠΚΕΙΜΕΝΟ</translation>
    </message>
    <message>
        <location filename="../list/list.cpp" line="179"/>
        <source>TEXT</source>
        <translation>ΚΕΙΜΕΝΟ</translation>
    </message>
    <message>
        <location filename="../list/list.cpp" line="182"/>
        <source>INSERT</source>
        <translation>ΕΙΣΑΓΩΓΗ</translation>
    </message>
    <message>
        <location filename="../list/list.cpp" line="185"/>
        <source>Name</source>
        <translation>Όνομα</translation>
    </message>
    <message>
        <location filename="../list/list.cpp" line="187"/>
        <source>Insertion point</source>
        <translation>Σημείο εισαγωγής</translation>
    </message>
    <message>
        <location filename="../list/list.cpp" line="190"/>
        <source>Scale</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../list/list.cpp" line="193"/>
        <source>Rotation</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../list/list.cpp" line="199"/>
        <source>Columns/Rows</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../list/list.cpp" line="203"/>
        <source>Column/Row Spacing</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../list/list.cpp" line="210"/>
        <source>POLYLINE</source>
        <translation>ΠΟΛΥΓΡΑΜΜΗ</translation>
    </message>
    <message>
        <location filename="../list/list.cpp" line="211"/>
        <source>Closed</source>
        <translation>Κλειστή</translation>
    </message>
    <message>
        <location filename="../list/list.cpp" line="212"/>
        <source>No</source>
        <translation>Όχι</translation>
    </message>
    <message>
        <location filename="../list/list.cpp" line="212"/>
        <source>Yes</source>
        <translation>Ναι</translation>
    </message>
    <message>
        <location filename="../list/list.cpp" line="213"/>
        <source>Vertices</source>
        <translation>Κορυφές</translation>
    </message>
    <message>
        <source>curvature</source>
        <translatorcomment>CHECKME</translatorcomment>
        <translation type="obsolete">καμπυλότητα</translation>
    </message>
    <message>
        <location filename="../list/list.cpp" line="227"/>
        <source>IMAGE</source>
        <translation>ΕΙΚΟΝΑ</translation>
    </message>
    <message>
        <location filename="../list/list.cpp" line="230"/>
        <source>SPLINE</source>
        <translation>SPLINE</translation>
    </message>
    <message>
        <location filename="../list/list.cpp" line="233"/>
        <source>SPLINEPOINTS</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../list/list.cpp" line="236"/>
        <source>HATCH</source>
        <translation>ΔΙΑΓΡΑΜΜΙΣΗ</translation>
    </message>
    <message>
        <location filename="../list/list.cpp" line="239"/>
        <source>DIMLEADER</source>
        <translation>ΔΙΑΣΤΑΣΗΟΔΗΓΟΣ</translation>
    </message>
    <message>
        <location filename="../list/list.cpp" line="242"/>
        <source>DIMALIGNED</source>
        <translatorcomment>CHECKME ΣΤΟΙΧΙΣΜΕΝΗ &apos;Η ΕΥΘΥΓΡΑΜΜΙΣΜΕΝΗ ΚΑΙ ΓΙΑΤΙ ΚΑΙ ΠΡΟΣΟΧΗ ΣΤΑ ΑΛΛΑ</translatorcomment>
        <translation>ΔΙΑΣΤΑΣΗΣΤΟΙΧΙΣΜΕΝΗ</translation>
    </message>
    <message>
        <location filename="../list/list.cpp" line="245"/>
        <source>DIMLINEAR</source>
        <translation>ΔΙΑΣΤΑΣΗΓΡΑΜΜΙΚΗ</translation>
    </message>
    <message>
        <location filename="../list/list.cpp" line="248"/>
        <source>DIMRADIAL</source>
        <translation>ΔΙΑΣΤΑΣΗΑΚΤΙΝΙΚΗ</translation>
    </message>
    <message>
        <location filename="../list/list.cpp" line="251"/>
        <source>DIMDIAMETRIC</source>
        <translation>ΔΙΑΣΤΑΣΗΔΙΑΜΕΤΡΙΚΗ</translation>
    </message>
    <message>
        <location filename="../list/list.cpp" line="254"/>
        <source>DIMANGULAR</source>
        <translation>ΔΙΑΣΤΑΣΗΓΩΝΙΑΚΗ</translation>
    </message>
    <message>
        <location filename="../list/list.cpp" line="257"/>
        <source>UNKNOWN</source>
        <translation>ΑΓΝΩΣΤΟ</translation>
    </message>
</context>
<context>
    <name>LC_SameProp</name>
    <message>
        <location filename="../sameprop/sameprop.cpp" line="21"/>
        <location filename="../sameprop/sameprop.cpp" line="28"/>
        <source>Same properties</source>
        <translation>Ίδιες ιδιότητες</translation>
    </message>
    <message>
        <location filename="../sameprop/sameprop.cpp" line="41"/>
        <source>select original entity:</source>
        <translation>επιλέξτε την αρχική οντότητα:</translation>
    </message>
    <message>
        <location filename="../sameprop/sameprop.cpp" line="43"/>
        <source>select entities to change</source>
        <translation>επιλέξτε τις οντότητες προς αλλαγή</translation>
    </message>
</context>
<context>
    <name>LC_Sample</name>
    <message>
        <location filename="../sample/sample.cpp" line="26"/>
        <location filename="../sample/sample.cpp" line="33"/>
        <source>Sample plugin</source>
        <translation>Δείγμα προσθέτου</translation>
    </message>
</context>
<context>
    <name>PicFile</name>
    <message>
        <location filename="../picfile/picfile.cpp" line="36"/>
        <source>Read PIC file</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../picfile/picfile.cpp" line="42"/>
        <source>import PIC file</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>dibPunto</name>
    <message>
        <location filename="../asciifile/asciifile.cpp" line="229"/>
        <source>Read ascii points</source>
        <translation>Ανάγνωση σημείων ascii</translation>
    </message>
    <message>
        <location filename="../asciifile/asciifile.cpp" line="235"/>
        <source>File...</source>
        <translation>Αρχείο...</translation>
    </message>
    <message>
        <location filename="../asciifile/asciifile.cpp" line="242"/>
        <source>Format:</source>
        <translation>Τύπος:</translation>
    </message>
    <message>
        <location filename="../asciifile/asciifile.cpp" line="244"/>
        <source>Space Separator</source>
        <translation>Διάστημα διαχωριστικό</translation>
    </message>
    <message>
        <location filename="../asciifile/asciifile.cpp" line="244"/>
        <source>Tab Separator</source>
        <translation>Στηλοθέτης διαχωριστικό</translation>
    </message>
    <message>
        <location filename="../asciifile/asciifile.cpp" line="244"/>
        <source>Comma Separator</source>
        <translation>Κόμμα διαχωριστικό</translation>
    </message>
    <message>
        <location filename="../asciifile/asciifile.cpp" line="244"/>
        <source>Space in Columns</source>
        <translation>Διάστημα σε στήλες</translation>
    </message>
    <message>
        <location filename="../asciifile/asciifile.cpp" line="244"/>
        <source>*.odb for Psion 2</source>
        <translation>*.odb for Psion 2</translation>
    </message>
    <message>
        <location filename="../asciifile/asciifile.cpp" line="246"/>
        <source>Connect points</source>
        <translation>Σύνδεση σημείων</translation>
    </message>
    <message>
        <location filename="../asciifile/asciifile.cpp" line="254"/>
        <source>2D Point</source>
        <translation>Σημείο 2Δ</translation>
    </message>
    <message>
        <location filename="../asciifile/asciifile.cpp" line="254"/>
        <source>Draw 2D Point</source>
        <translation>Σχεδίαση σημείου 2Δ</translation>
    </message>
    <message>
        <location filename="../asciifile/asciifile.cpp" line="255"/>
        <source>3D Point</source>
        <translation>Σημείο 3Δ</translation>
    </message>
    <message>
        <location filename="../asciifile/asciifile.cpp" line="255"/>
        <source>Draw 3D Point</source>
        <translation>Σχεδίαση σημείου 3Δ</translation>
    </message>
    <message>
        <location filename="../asciifile/asciifile.cpp" line="256"/>
        <source>Point Number</source>
        <translation>Αριθμός σημείου</translation>
    </message>
    <message>
        <location filename="../asciifile/asciifile.cpp" line="256"/>
        <source>Draw point number</source>
        <translation>Σχεδίαση αριθμού σημείου</translation>
    </message>
    <message>
        <location filename="../asciifile/asciifile.cpp" line="257"/>
        <source>Point Elevation</source>
        <translation>Ανύψωση σημείου</translation>
    </message>
    <message>
        <location filename="../asciifile/asciifile.cpp" line="257"/>
        <source>Draw point elevation</source>
        <translation>Σχεδίαση ανύψωσης σημείου</translation>
    </message>
    <message>
        <location filename="../asciifile/asciifile.cpp" line="258"/>
        <source>Point Code</source>
        <translation>Κωδικός σημείου</translation>
    </message>
    <message>
        <location filename="../asciifile/asciifile.cpp" line="258"/>
        <source>Draw point code</source>
        <translation>Σχεδίαση κωδικού σημείου</translation>
    </message>
    <message>
        <location filename="../asciifile/asciifile.cpp" line="272"/>
        <source>Accept</source>
        <translation>Αποδοχή</translation>
    </message>
    <message>
        <location filename="../asciifile/asciifile.cpp" line="277"/>
        <source>Cancel</source>
        <translation>Ακύρωση</translation>
    </message>
    <message>
        <location filename="../asciifile/asciifile.cpp" line="307"/>
        <source>Select file</source>
        <translation>Επιλογή αρχείου</translation>
    </message>
    <message>
        <location filename="../asciifile/asciifile.cpp" line="314"/>
        <source>Point 2D layer is empty</source>
        <translatorcomment>CHECKME ALL TRANSLATIONS BELOW SOS μπορεί να είναι &quot;κωδικών σημείων&quot;, &quot;αριθμών (των) σημείων&quot;</translatorcomment>
        <translation>Η στρώση 2Δ του σημείου είναι κενή</translation>
    </message>
    <message>
        <location filename="../asciifile/asciifile.cpp" line="317"/>
        <source>Point 3D layer is empty</source>
        <translation>Η στρώση 3Δ του σημείου είναι κενή</translation>
    </message>
    <message>
        <location filename="../asciifile/asciifile.cpp" line="320"/>
        <source>Point elevation layer is empty</source>
        <translation>Η στρώση ανύψωσης του σημείου είναι κενή</translation>
    </message>
    <message>
        <location filename="../asciifile/asciifile.cpp" line="321"/>
        <source>Point elevation height is empty</source>
        <translation>Το ύψος ανύψωσης του σημείου είναι κενό</translation>
    </message>
    <message>
        <location filename="../asciifile/asciifile.cpp" line="322"/>
        <source>Point elevation separation is empty</source>
        <translation>Ο διαχωρισμός ανύψωσης του σημείου είναι κενός</translation>
    </message>
    <message>
        <location filename="../asciifile/asciifile.cpp" line="325"/>
        <source>Point number layer is empty</source>
        <translation>Η στρώση αριθμού του σημείου είναι κενή</translation>
    </message>
    <message>
        <location filename="../asciifile/asciifile.cpp" line="326"/>
        <source>Point number height is empty</source>
        <translation>Το ύψος αριθμού του σημείου είναι κενό</translation>
    </message>
    <message>
        <location filename="../asciifile/asciifile.cpp" line="327"/>
        <source>Point number separation is empty</source>
        <translation>Ο διαχωρισμός αριθμού του σημείου είναι κενός</translation>
    </message>
    <message>
        <location filename="../asciifile/asciifile.cpp" line="330"/>
        <source>Point code layer is empty</source>
        <translation>Η στρώση κωδικού του σημείου είναι κενή</translation>
    </message>
    <message>
        <location filename="../asciifile/asciifile.cpp" line="331"/>
        <source>Point code height is empty</source>
        <translation>Το ύψος κωδικού του σημείου είναι κενό</translation>
    </message>
    <message>
        <location filename="../asciifile/asciifile.cpp" line="332"/>
        <source>Point code separation is empty</source>
        <translation>Ο διαχωρισμός κωδικού του σημείου είναι κενός</translation>
    </message>
    <message>
        <location filename="../asciifile/asciifile.cpp" line="360"/>
        <source>The file %1 not exist</source>
        <translation>Το αρχείο %1 δεν υπάρχει</translation>
    </message>
    <message>
        <location filename="../asciifile/asciifile.cpp" line="365"/>
        <source>Can&apos;t open the file %1</source>
        <translation>Δεν είναι δυνατό το άνοιγμα του αρχείου %1</translation>
    </message>
</context>
<context>
    <name>dibSHP</name>
    <message>
        <location filename="../importshp/importshp.cpp" line="59"/>
        <source>File...</source>
        <translation>Αρχείο...</translation>
    </message>
    <message>
        <location filename="../importshp/importshp.cpp" line="67"/>
        <source>File type:</source>
        <translation>Τύπος αρχείου:</translation>
    </message>
    <message>
        <location filename="../importshp/importshp.cpp" line="75"/>
        <source>Layer</source>
        <translation>Στρώση</translation>
    </message>
    <message>
        <location filename="../importshp/importshp.cpp" line="56"/>
        <source>Import ESRI Shapefile</source>
        <translation>Εισαγωγή ESRI Shapefile</translation>
    </message>
    <message>
        <location filename="../importshp/importshp.cpp" line="68"/>
        <location filename="../importshp/importshp.cpp" line="266"/>
        <source>Unknown</source>
        <translation>Άγνωστο</translation>
    </message>
    <message>
        <location filename="../importshp/importshp.cpp" line="76"/>
        <location filename="../importshp/importshp.cpp" line="89"/>
        <location filename="../importshp/importshp.cpp" line="102"/>
        <location filename="../importshp/importshp.cpp" line="115"/>
        <source>Current</source>
        <translation>Τρέχον</translation>
    </message>
    <message>
        <location filename="../importshp/importshp.cpp" line="77"/>
        <location filename="../importshp/importshp.cpp" line="90"/>
        <location filename="../importshp/importshp.cpp" line="103"/>
        <location filename="../importshp/importshp.cpp" line="116"/>
        <source>From data:</source>
        <translation>Από δεδομένα:</translation>
    </message>
    <message>
        <location filename="../importshp/importshp.cpp" line="88"/>
        <source>Color</source>
        <translation>Χρώμα</translation>
    </message>
    <message>
        <location filename="../importshp/importshp.cpp" line="101"/>
        <source>Line type</source>
        <translation>Τύπος γραμμής</translation>
    </message>
    <message>
        <location filename="../importshp/importshp.cpp" line="114"/>
        <source>Width</source>
        <translation>Πλάτος</translation>
    </message>
    <message>
        <location filename="../importshp/importshp.cpp" line="127"/>
        <location filename="../importshp/importshp.cpp" line="213"/>
        <source>Point</source>
        <translation>Σημείο</translation>
    </message>
    <message>
        <location filename="../importshp/importshp.cpp" line="128"/>
        <source>as Point</source>
        <translation>ως Σημείο</translation>
    </message>
    <message>
        <location filename="../importshp/importshp.cpp" line="129"/>
        <source>as Label:</source>
        <translation>ως Ετικέτα:</translation>
    </message>
    <message>
        <location filename="../importshp/importshp.cpp" line="141"/>
        <source>Accept</source>
        <translation>Αποδοχή</translation>
    </message>
    <message>
        <location filename="../importshp/importshp.cpp" line="142"/>
        <source>Cancel</source>
        <translation>Ακύρωση</translation>
    </message>
    <message>
        <location filename="../importshp/importshp.cpp" line="167"/>
        <source>Select file</source>
        <translation>Επιλογή αρχείου</translation>
    </message>
    <message>
        <location filename="../importshp/importshp.cpp" line="217"/>
        <source>Point+Measure</source>
        <translatorcomment>CHECKME και τα παρακάτω</translatorcomment>
        <translation>Σημείο+Μέτρο</translation>
    </message>
    <message>
        <location filename="../importshp/importshp.cpp" line="221"/>
        <source>3D Point</source>
        <translation>Σημείο 3Δ</translation>
    </message>
    <message>
        <location filename="../importshp/importshp.cpp" line="225"/>
        <source>Multi Point</source>
        <translation>Πολλαπλά σημεία</translation>
    </message>
    <message>
        <location filename="../importshp/importshp.cpp" line="229"/>
        <source>Multi Point+Measure</source>
        <translation>Πολλαπλά σημεία+Μέτρο</translation>
    </message>
    <message>
        <location filename="../importshp/importshp.cpp" line="233"/>
        <source>3D Multi Point</source>
        <translation>Πολλαπλά σημεία 3Δ</translation>
    </message>
    <message>
        <location filename="../importshp/importshp.cpp" line="237"/>
        <source>Arc</source>
        <translation>Τόξο</translation>
    </message>
    <message>
        <location filename="../importshp/importshp.cpp" line="241"/>
        <source>Arc+Measure</source>
        <translation>Τόξο+Μέτρο</translation>
    </message>
    <message>
        <location filename="../importshp/importshp.cpp" line="245"/>
        <source>3D Arc</source>
        <translation>Τόξο 3Δ</translation>
    </message>
    <message>
        <location filename="../importshp/importshp.cpp" line="249"/>
        <source>Polygon</source>
        <translation>Πολύγωνο</translation>
    </message>
    <message>
        <location filename="../importshp/importshp.cpp" line="253"/>
        <source>Polygon+Measure</source>
        <translation>Πολύγωνο+Μέτρο</translation>
    </message>
    <message>
        <location filename="../importshp/importshp.cpp" line="257"/>
        <source>3D Polygon</source>
        <translation>Πολύγωνο 3Δ</translation>
    </message>
    <message>
        <source>Poligon</source>
        <translation type="obsolete">Πολύγωνο</translation>
    </message>
    <message>
        <source>Poligon+Measure</source>
        <translation type="obsolete">Πολύγωνο+Μέτρο</translation>
    </message>
    <message>
        <source>3D Poligon</source>
        <translation type="obsolete">Πολύγωνο 3Δ</translation>
    </message>
    <message>
        <location filename="../importshp/importshp.cpp" line="261"/>
        <source>Multipatch</source>
        <translatorcomment>CHECKME από spline patch; θα είναι λάθος και αλλού. να δω το patch πώς θα μεταφραστεί.</translatorcomment>
        <translation>Πολυκαμπύλη</translation>
    </message>
    <message>
        <location filename="../importshp/importshp.cpp" line="281"/>
        <source>The file %1 not have extension .shp</source>
        <translation>Το αρχείο %1 δεν έχει επέκταση .shp</translation>
    </message>
    <message>
        <location filename="../importshp/importshp.cpp" line="286"/>
        <source>The file %1 not exist</source>
        <translation>Το αρχείο %1 δεν υπάρχει</translation>
    </message>
</context>
<context>
    <name>lc_Geardlg</name>
    <message>
        <location filename="../gear/gear.cpp" line="66"/>
        <source>Draw a gear</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../gear/gear.cpp" line="71"/>
        <source>Number of teeth</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../gear/gear.cpp" line="79"/>
        <source>Circular pitch</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../gear/gear.cpp" line="87"/>
        <source>Pressure angle (deg)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../gear/gear.cpp" line="95"/>
        <source>Addendum</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../gear/gear.cpp" line="103"/>
        <source>Dedendum</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../gear/gear.cpp" line="111"/>
        <source>Type</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../gear/gear.cpp" line="114"/>
        <source>Spur</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../gear/gear.cpp" line="115"/>
        <source>Ring</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../gear/gear.cpp" line="119"/>
        <source>Accept</source>
        <translation type="unfinished">Αποδοχή</translation>
    </message>
    <message>
        <location filename="../gear/gear.cpp" line="124"/>
        <source>Cancel</source>
        <translation type="unfinished">Ακύρωση</translation>
    </message>
</context>
<context>
    <name>lc_Listdlg</name>
    <message>
        <location filename="../list/list.cpp" line="274"/>
        <source>List entities</source>
        <translation>Απαρίθμηση οντοτήτων</translation>
    </message>
</context>
<context>
    <name>lc_Sampledlg</name>
    <message>
        <location filename="../sample/sample.cpp" line="54"/>
        <source>Draw line</source>
        <translation>Σχεδίαση γραμμής</translation>
    </message>
    <message>
        <location filename="../sample/sample.cpp" line="60"/>
        <source>Start X:</source>
        <translation>Αρχικό X:</translation>
    </message>
    <message>
        <location filename="../sample/sample.cpp" line="66"/>
        <source>Start Y:</source>
        <translation>Αρχικό Y:</translation>
    </message>
    <message>
        <location filename="../sample/sample.cpp" line="72"/>
        <source>End X:</source>
        <translation>Τελικό X:</translation>
    </message>
    <message>
        <location filename="../sample/sample.cpp" line="78"/>
        <source>End Y:</source>
        <translation>Τελικό Y:</translation>
    </message>
    <message>
        <location filename="../sample/sample.cpp" line="86"/>
        <source>Accept</source>
        <translation>Αποδοχή</translation>
    </message>
    <message>
        <location filename="../sample/sample.cpp" line="91"/>
        <source>Cancel</source>
        <translation>Ακύρωση</translation>
    </message>
    <message>
        <location filename="../sample/sample.cpp" line="107"/>
        <source>Start X is empty</source>
        <translation>Το αρχικό X είναι κενό</translation>
    </message>
    <message>
        <location filename="../sample/sample.cpp" line="108"/>
        <source>Start Y is empty</source>
        <translation>Το αρχικό Y είναι κενό</translation>
    </message>
    <message>
        <location filename="../sample/sample.cpp" line="109"/>
        <source>End X is empty</source>
        <translation>Το τελικό X είναι κενό</translation>
    </message>
    <message>
        <location filename="../sample/sample.cpp" line="110"/>
        <source>End Y is empty</source>
        <translation>Το τελικό Y είναι κενό</translation>
    </message>
    <message>
        <location filename="../sample/sample.cpp" line="132"/>
        <source>Sample plugin</source>
        <translation>Δείγμα προσθέτου</translation>
    </message>
</context>
<context>
    <name>picPunto</name>
    <message>
        <location filename="../picfile/picfile.cpp" line="65"/>
        <source>File...</source>
        <translation>Αρχείο...</translation>
    </message>
    <message>
        <location filename="../picfile/picfile.cpp" line="75"/>
        <source>Scale:</source>
        <translation>Κλίμακα:</translation>
    </message>
    <message>
        <location filename="../picfile/picfile.cpp" line="79"/>
        <source>Accept</source>
        <translation>Αποδοχή</translation>
    </message>
    <message>
        <location filename="../picfile/picfile.cpp" line="83"/>
        <source>Cancel</source>
        <translation>Ακύρωση</translation>
    </message>
    <message>
        <location filename="../picfile/picfile.cpp" line="111"/>
        <source>Select file</source>
        <translation>Επιλογή αρχείου</translation>
    </message>
    <message>
        <location filename="../picfile/picfile.cpp" line="119"/>
        <source>Scale Factor is empty or invalid</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../picfile/picfile.cpp" line="132"/>
        <source>The file %1 not exist</source>
        <translation>Το αρχείο %1 δεν υπάρχει</translation>
    </message>
    <message>
        <location filename="../picfile/picfile.cpp" line="137"/>
        <source>Can&apos;t open the file %1</source>
        <translation>Δεν είναι δυνατό το άνοιγμα του αρχείου %1</translation>
    </message>
    <message>
        <location filename="../picfile/picfile.cpp" line="144"/>
        <source>%1 objects imported</source>
        <translation>%1 αντικείμενα εισήχθησαν</translation>
    </message>
    <message>
        <location filename="../picfile/picfile.cpp" line="166"/>
        <source>picPunto drawLine: first point is empty %1</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../picfile/picfile.cpp" line="179"/>
        <source>picPunto drawLine: next point is empty %1</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../picfile/picfile.cpp" line="258"/>
        <location filename="../picfile/picfile.cpp" line="267"/>
        <source>format error in %1</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>plot</name>
    <message>
        <location filename="../plotequation/plot.cpp" line="21"/>
        <location filename="../plotequation/plot.cpp" line="28"/>
        <source>Plot plugin</source>
        <translation>Πρόσθετο σχεδιογράφησης</translation>
    </message>
    <message>
        <source>Draw</source>
        <translation type="obsolete">Σχεδίαση</translation>
    </message>
</context>
<context>
    <name>plotDialog</name>
    <message>
        <location filename="../plotequation/plotdialog.cpp" line="15"/>
        <source>Plot equation</source>
        <translation>Σχεδιογράφηση εξίσωσης</translation>
    </message>
    <message>
        <location filename="../plotequation/plotdialog.cpp" line="18"/>
        <source>This plugin allows you to plot mathematical equations.
If you don&apos;t want to use the parametric form, just leave out &quot;Equation2&quot;.
You can use pi when you need the value of pi (i.e. (3*pi)).
Use t or x in your equation as a variable/parameter.
</source>
        <translation>Το συγκεκριμένο πρόσθετο επιτρέπει τη σχεδιογράφηση μαθηματικών εξισώσεων.
Σε περίπτωση που δεν επιθυμείτε τη χρήση της παραμετρικής μορφής, απλά αγνοήστε το &quot;Εξίσωση 2&quot;.
Μπορείτε να χρησιμοποιήσετε το pi σε περίπτωση που χρειάζεστε την τιμή του π (π.χ. (3*pi)).
Χρησιμοποιήστε το t ή το x στην εξίσωσή σας ως μεταβλητή/παράμετρο.</translation>
    </message>
    <message>
        <location filename="../plotequation/plotdialog.cpp" line="22"/>
        <source>Equation 1:</source>
        <translation>Εξίσωση 1:</translation>
    </message>
    <message>
        <location filename="../plotequation/plotdialog.cpp" line="23"/>
        <source>Equation 2:</source>
        <translation>Εξίσωση 2:</translation>
    </message>
    <message>
        <location filename="../plotequation/plotdialog.cpp" line="26"/>
        <source>start value:</source>
        <translation>αρχική τιμή:</translation>
    </message>
    <message>
        <location filename="../plotequation/plotdialog.cpp" line="27"/>
        <source>end value:</source>
        <translation>τελική τιμή:</translation>
    </message>
    <message>
        <location filename="../plotequation/plotdialog.cpp" line="28"/>
        <source>step size:</source>
        <translation>μέγεθος βήματος:</translation>
    </message>
    <message>
        <location filename="../plotequation/plotdialog.cpp" line="32"/>
        <source>Draw</source>
        <translation>Σχεδίαση</translation>
    </message>
    <message>
        <location filename="../plotequation/plotdialog.cpp" line="33"/>
        <source>Cancel</source>
        <translation>Ακύρωση</translation>
    </message>
    <message>
        <location filename="../plotequation/plotdialog.cpp" line="59"/>
        <source>Line Segments</source>
        <comment>Plot Equation to generate RS_Line segments</comment>
        <translation>Τομείς Γραμμής</translation>
    </message>
    <message>
        <location filename="../plotequation/plotdialog.cpp" line="60"/>
        <source>Polyline</source>
        <comment>Plot Equation to generate RS_Polyline</comment>
        <translation>Πολυγραμμή</translation>
    </message>
    <message>
        <location filename="../plotequation/plotdialog.cpp" line="61"/>
        <source>SplinePoints</source>
        <comment>Plot Equation to generate 2nd spline by LC_SplinePoints</comment>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>pointBox</name>
    <message>
        <location filename="../asciifile/asciifile.cpp" line="175"/>
        <source>Layer:</source>
        <translation>Στρώση:</translation>
    </message>
</context>
<context>
    <name>textBox</name>
    <message>
        <location filename="../asciifile/asciifile.cpp" line="207"/>
        <source>Style:</source>
        <translation>Στιλ:</translation>
    </message>
    <message>
        <location filename="../asciifile/asciifile.cpp" line="208"/>
        <source>Height:</source>
        <translation>Ύψος:</translation>
    </message>
    <message>
        <source>Heigth:</source>
        <translation type="obsolete">Ύψος:</translation>
    </message>
    <message>
        <location filename="../asciifile/asciifile.cpp" line="209"/>
        <source>Separation</source>
        <translation>Διαχωρισμός</translation>
    </message>
</context>
</TS>
